<?php

return [
    'number.decimals_separator' => ',',
    'number.thousands_separator' => '.',
    'None' => 'Nessuno',
    'Edit' => 'Modifica',
    'Remove' => 'Cancella',
    'Yes' => 'Si',
    'No' => 'No',
    'cancel' => 'annulla',
    'or' => 'o',
    'Yellow' => 'Giallo',
    'Blue' => 'Blu',
    'Green' => 'Verde',
    'Purple' => 'Viola',
    'Red' => 'Rosso',
    'Orange' => 'Arancione',
    'Grey' => 'Grigio',
    'Brown' => 'Marrone',
    'Deep Orange' => 'Arancio scuro',
    'Dark Grey' => 'Grigio scuro',
    'Pink' => 'Rosa',
    'Teal' => 'Verde foglia di tè',
    'Cyan' => 'Ciano',
    'Lime' => 'Verde lime',
    'Light Green' => 'Verde chiaro',
    'Amber' => 'Ambra',
    'Save' => 'Salva',
    'Login' => 'Accedi',
    'Official website:' => 'Sito web ufficiale:',
    'Unassigned' => 'Non assegnato',
    'View this task' => 'Visualizza questo compito',
    'Remove user' => 'Cancella un utente',
    'Do you really want to remove this user: "%s"?' => 'Veramente vuoi cancellare questo utente: "%s" ?',
    'All users' => 'Tutti gli utenti',
    'Username' => 'Nome utente',
    'Password' => 'Password',
    'Administrator' => 'Amministratore',
    'Sign in' => 'Accedi',
    'Users' => 'Utenti',
    'Forbidden' => 'Vietato',
    'Access Forbidden' => 'Accesso vietato',
    'Edit user' => 'Modifica un utente',
    'Logout' => 'Esci',
    'Bad username or password' => 'Utente o password errati',
    'Edit project' => 'Modifica progetto',
    'Name' => 'Nome',
    'Projects' => 'Progetti',
    'No project' => 'Nessun progetto',
    'Project' => 'Progetto',
    'Status' => 'Stato',
    'Tasks' => 'Task',
    'Board' => 'Bacheca',
    'Actions' => 'Azioni',
    'Inactive' => 'Inattivo',
    'Active' => 'Attivo',
    'Unable to update this board.' => 'Impossibile aggiornare questa bacheca.',
    'Disable' => 'Disattiva',
    'Enable' => 'Attiva',
    'New project' => 'Nuovo progetto',
    'Do you really want to remove this project: "%s"?' => 'Vuoi davvero eliminare il seguente progetto: "%s" ?',
    'Remove project' => 'Cancella il progetto',
    'Edit the board for "%s"' => 'Modifica la bacheca per "%s"',
    'Add a new column' => 'Aggiungi una nuova colonna',
    'Title' => 'Titolo',
    'Assigned to %s' => 'Assegnato a %s',
    'Remove a column' => 'Cancella questa colonna',
    'Unable to remove this column.' => 'Impossibile cancellare questa colonna.',
    'Do you really want to remove this column: "%s"?' => 'Desideri davvero cancellare questa colonna: "%s" ?',
    'Settings' => 'Impostazioni',
    'Application settings' => 'Impostazioni dell\'applicazione',
    'Language' => 'Lingua',
    'Webhook token:' => 'Identificatore (token) per i webhooks :',
    'API token:' => 'Token dell\'API:',
    'Database size:' => 'Dimensioni della base dati:',
    'Download the database' => 'Scaricare la base dati',
    'Optimize the database' => 'Ottimizare la base dati',
    '(VACUUM command)' => '(Comando VACUUM)',
    '(Gzip compressed Sqlite file)' => '(File Sqlite compresso in Gzip)',
    'Close a task' => 'Chiudi un compito',
    'Column' => 'Colonna',
    'Color' => 'Colore',
    'Assignee' => 'Assegnatario',
    'Create another task' => 'Crea un nuovo compito',
    'New task' => 'Nuovo compito',
    'Open a task' => 'Apri un compito',
    'Do you really want to open this task: "%s"?' => 'Desideri davvero aprire questo compito: "%s" ?',
    'Back to the board' => 'Torna alla bacheca',
    'There is nobody assigned' => 'Nessuno è assegnato a questo compito',
    'Column on the board:' => 'Colonna sulla bacheca: ',
    'Close this task' => 'Chiudi questo compito',
    'Open this task' => 'Apri questo compito',
    'There is no description.' => 'Nessuna descrizione presente.',
    'Add a new task' => 'Aggiungere un nuovo compito',
    'The username is required' => 'Si richiede un nome di utente',
    'The maximum length is %d characters' => 'La lunghezza massima è di %d caratteri',
    'The minimum length is %d characters' => 'La lunghezza minima è di %d caratteri',
    'The password is required' => 'Si richiede una password',
    'This value must be an integer' => 'questo valore deve essere un intero',
    'The username must be unique' => 'Il nome di utente deve essere unico',
    'The user id is required' => 'Si richiede l\'identificatore dell\'utente',
    'Passwords don\'t match' => 'Le password non corrispondono',
    'The confirmation is required' => 'Si richiede una conferma',
    'The project is required' => 'Si richiede il progetto',
    'The id is required' => 'Si richiede l\'identificatore',
    'The project id is required' => 'Si richiede l\'identificatore del progetto',
    'The project name is required' => 'Si richiede il nome del progetto',
    'The title is required' => 'Si richiede un titolo',
    'Settings saved successfully.' => 'Impostazioni salvate con successo.',
    'Unable to save your settings.' => 'Impossibile salvare le impostazioni.',
    'Database optimization done.' => 'Ottimizzazione della base dati conclusa.',
    'Your project has been created successfully.' => 'Il tuo progetto è stato creato con successo.',
    'Unable to create your project.' => 'Impossibile creare il progetto.',
    'Project updated successfully.' => 'Progetto aggiornato con successo.',
    'Unable to update this project.' => 'Impossibile aggiornare il progetto.',
    'Unable to remove this project.' => 'Impossibile cancellare questo progetto.',
    'Project removed successfully.' => 'Progetto cancellato con successo.',
    'Project activated successfully.' => 'Progetto attivato con successo.',
    'Unable to activate this project.' => 'Impossibile attivare il progetto.',
    'Project disabled successfully.' => 'Progetto disattivato con successo.',
    'Unable to disable this project.' => 'Impossibile disattivare il progetto.',
    'Unable to open this task.' => 'Impossibile aprire questo compito.',
    'Task opened successfully.' => 'Il compito è stato aperto con successo.',
    'Unable to close this task.' => 'Impossibile chiudere questo compito.',
    'Task closed successfully.' => 'Task chiuso con successo.',
    'Unable to update your task.' => 'Impossibile modificare questo compito.',
    'Task updated successfully.' => 'Task modificato con successo.',
    'Unable to create your task.' => 'Impossibile creare questo compito.',
    'Task created successfully.' => 'Task creato con successo.',
    'User created successfully.' => 'Utente creato con successo.',
    'Unable to create your user.' => 'Impossibile creare l\'utente.',
    'User updated successfully.' => 'Utente aggiornato con successo.',
    'User removed successfully.' => 'Utente cancellato con successo.',
    'Unable to remove this user.' => 'Impossibile cancellare questo utente.',
    'Board updated successfully.' => 'Bacheca aggiornata con successo.',
    'Ready' => 'Pronto',
    'Backlog' => 'In attesa',
    'Work in progress' => 'In corso',
    'Done' => 'Fatto',
    'Application version:' => 'Versione dell\'applicazione:',
    'Id' => 'ID',
    'Public link' => 'Link pubblico',
    'Timezone' => 'Fuso orario',
    'Sorry, I didn\'t find this information in my database!' => 'Spiacente, non ho trovato questa informazione sul database!',
    'Page not found' => 'Pagina non trovata',
    'Complexity' => 'Complessità',
    'Task limit' => 'Limite di compito',
    'Task count' => 'Numero di compito',
    'User' => 'Utente',
    'Comments' => 'Commenti',
    'Comment is required' => 'Si richiede un commento',
    'Comment added successfully.' => 'Commenti aggiunti con successo.',
    'Unable to create your comment.' => 'Impossibile creare questo commento.',
    'Due Date' => 'Data di scadenza',
    'Invalid date' => 'Data non valida',
    'Automatic actions' => 'Azioni automatiche',
    'Your automatic action has been created successfully.' => 'l\'azione automatica è stata creata con successo.',
    'Unable to create your automatic action.' => 'Impossibile creare quest\'azione automatica.',
    'Remove an action' => 'Cancellare un\'azione',
    'Unable to remove this action.' => 'Impossibile cancellare questa azione.',
    'Action removed successfully.' => 'Azione cancellata con successo.',
    'Automatic actions for the project "%s"' => 'Azioni automatiche per il progetto "%s"',
    'Add an action' => 'Aggiungi un\'azione',
    'Event name' => 'Nome dell\'evento',
    'Action' => 'Azione',
    'Event' => 'Evento',
    'When the selected event occurs execute the corresponding action.' => 'Quando si verifica l\'evento selezionato, eseguire l\'azione corrispondente.',
    'Next step' => 'Passo successivo',
    'Define action parameters' => 'Definire i parametri dell\'azione',
    'Do you really want to remove this action: "%s"?' => 'Vuoi davvero cancellare la seguente azione: "%s"?',
    'Remove an automatic action' => 'Cancella un\'azione automatica',
    'Assign the task to a specific user' => 'Assegna il compito ad un utente specifico',
    'Assign the task to the person who does the action' => 'Assegna il compito all\'utente che compie l\'azione',
    'Duplicate the task to another project' => 'Duplica il compito in altro progetto',
    'Move a task to another column' => 'Sposta un compito in un\'altra colonna',
    'Task modification' => 'Modifica di un compito',
    'Task creation' => 'Creazione di un compito',
    'Closing a task' => 'Chiusura di un compito',
    'Assign a color to a specific user' => 'Assegna un colore ad un utente specifico',
    'Position' => 'Posizione',
    'Duplicate to project' => 'Duplica in un altro progetto',
    'Duplicate' => 'Duplica',
    'Link' => 'Relazione',
    'Comment updated successfully.' => 'Commento aggiornato con successo.',
    'Unable to update your comment.' => 'Impossibile aggiornare questo commento.',
    'Remove a comment' => 'Cancella un commento',
    'Comment removed successfully.' => 'Commento cancellato con successo.',
    'Unable to remove this comment.' => 'Impossibile cancellare questo commento.',
    'Do you really want to remove this comment?' => 'Vuoi davvero cancellare questo commento?',
    'Current password for the user "%s"' => 'Password attuale per l\'utente "%s"',
    'The current password is required' => 'Si richiede la password attuale',
    'Wrong password' => 'Password errata',
    'Unknown' => 'Sconociuto',
    'Last logins' => 'Ultimi accessi',
    'Login date' => 'Data di accesso',
    'Authentication method' => 'Metodo di autenticazione',
    'IP address' => 'Indirizzo IP',
    'User agent' => 'User agent',
    'Persistent connections' => 'Connessioni persistenti',
    'No session.' => 'Non esiste sessione.',
    'Expiration date' => 'Data di scadenza',
    'Remember Me' => 'Ricordami',
    'Creation date' => 'Data di creazione',
    'Everybody' => 'Tutti',
    'Open' => 'Aperto',
    'Closed' => 'Chiuso',
    'Search' => 'Cerca',
    'Nothing found.' => 'Non si è trovato nulla.',
    'Due date' => 'Data di scadenza',
    'Description' => 'Descrizione',
    '%d comments' => '%d commenti',
    '%d comment' => '%d commento',
    'Email address invalid' => 'Indirizzo Email non valido',
    'Your external account is not linked anymore to your profile.' => 'Il tuo account esterno non è più collegato al tuo profilo.',
    'Unable to unlink your external account.' => 'Impossibile scollegare il tuo account esterno.',
    'External authentication failed' => 'Autenticazione esterna fallita',
    'Your external account is linked to your profile successfully.' => 'Il tuo account esterno è stato collegato al tuo profilo con successo.',
    'Email' => 'Email',
    'Task removed successfully.' => 'Task cancellato con successo.',
    'Unable to remove this task.' => 'Impossibile cancellare questo compito.',
    'Remove a task' => 'Cancella un compito',
    'Do you really want to remove this task: "%s"?' => 'Vuoi davvero cancellare questo compito: "%s"?',
    'Assign automatically a color based on a category' => 'Assegna un colore in modo automatico basandosi sulla categoria',
    'Assign automatically a category based on a color' => 'Assegna una categoria in modo automatico basandosi sul colore',
    'Task creation or modification' => 'Creazione o modifica di compito',
    'Category' => 'Categoria',
    'Category:' => 'Categoria:',
    'Categories' => 'Categorie',
    'Your category has been created successfully.' => 'La tua categoria è stata creata con successo.',
    'This category has been updated successfully.' => 'La tua categoria è stata aggiornata con successo.',
    'Unable to update this category.' => 'Impossibile aggiornare la tua categoria.',
    'Remove a category' => 'Cancella una categoria',
    'Category removed successfully.' => 'Categoria cancellata con successo.',
    'Unable to remove this category.' => 'Impossibile cancellare questa categoria.',
    'Category modification for the project "%s"' => 'Modifica della categoria per il progetto "%s"',
    'Category Name' => 'Nome della categoria',
    'Add a new category' => 'Aggiungere una nuova categoria',
    'Do you really want to remove this category: "%s"?' => 'Vuoi davvero cancellare la seguente categoria: "%s"?',
    'All categories' => 'Tutte le categorie',
    'No category' => 'Senza categoria',
    'The name is required' => 'Si richiede un nome',
    'Remove a file' => 'Cancella un file',
    'Unable to remove this file.' => 'Impossibile cancellare questo file.',
    'File removed successfully.' => 'File cancellato con successo.',
    'Attach a document' => 'Allega un documento',
    'Do you really want to remove this file: "%s"?' => 'Vuoi davvero cancellare questo file: "%s"?',
    'Attachments' => 'Allegati',
    'Edit the task' => 'Modifica il compito',
    'Add a comment' => 'Aggiungi un commento',
    'Edit a comment' => 'Modifica un commento',
    'Summary' => 'Sommario',
    'Time tracking' => 'Monitoraggio delle tempistiche',
    'Estimate:' => 'Stimato:',
    'Spent:' => 'Trascorso:',
    'Do you really want to remove this sub-task?' => 'Vuoi davvero cancellare questo sotto-compito?',
    'Remaining:' => 'Rimangono',
    'hours' => 'ore',
    'estimated' => 'stimate',
    'Sub-Tasks' => 'Sotto-compito',
    'Add a sub-task' => 'Aggiungi un sotto-compito',
    'Original estimate' => 'Stima originale',
    'Create another sub-task' => 'Crea un altro sotto-compito',
    'Time spent' => 'Tempo trascorso',
    'Edit a sub-task' => 'Modifica un sotto-compito',
    'Remove a sub-task' => 'Cancella un sotto-compito',
    'The time must be a numeric value' => 'Il tempo deve essere un valore numerico',
    'Todo' => 'Da fare',
    'In progress' => 'In corso',
    'Sub-task removed successfully.' => 'Sotto-compito cancellato con successo.',
    'Unable to remove this sub-task.' => 'Impossibile cancellare questo sotto-compito.',
    'Sub-task updated successfully.' => 'Sotto-compito aggiornato con successo.',
    'Unable to update your sub-task.' => 'Impossibile aggiornare il tuo sotto-compito.',
    'Unable to create your sub-task.' => 'Impossibile creare il tuo sotto-compito.',
    'Maximum size: ' => 'Dimensioni massime: ',
    'Display another project' => 'Mostra un altro progetto',
    'Created by %s' => 'Creato da %s',
    'Tasks Export' => 'Export dei compito',
    'Start Date' => 'Data di inizio',
    'Execute' => 'Esegui',
    'Task Id' => 'Id del compito',
    'Creator' => 'Creatore',
    'Modification date' => 'Data di modifica',
    'Completion date' => 'Data di termine',
    'Clone' => 'Clona',
    'Project cloned successfully.' => 'Progetto clonato con successo.',
    'Unable to clone this project.' => 'Impossibile clonare questo progetto',
    'Enable email notifications' => 'Abilita le notifiche via email',
    'Task position:' => 'Posizione del compito:',
    'The task #%d has been opened.' => 'Il compito #%d è stato aperto.',
    'The task #%d has been closed.' => 'Il compito #%d è stato chiuso.',
    'Sub-task updated' => 'Sotto-compito aggiornato',
    'Title:' => 'Titolo',
    'Status:' => 'Stato',
    'Assignee:' => 'Assegnatario:',
    'Time tracking:' => 'Monitoraggio delle tempistiche:',
    'New sub-task' => 'Nuovo sotto-compito',
    'New attachment added "%s"' => 'Nuovo allegato aggiunto "%s"',
    'New comment posted by %s' => 'Nuovo commento aggiunto da "%s"',
    'New comment' => 'Nuovo commento',
    'Comment updated' => 'Commento aggiornato',
    'New subtask' => 'Nuovo sotto-compito',
    'I only want to receive notifications for these projects:' => 'Vorrei ricevere le notifiche solo da questi progetti:',
    'view the task on Kanboard' => 'visualizza il compito su Kanboard',
    'Public access' => 'Accesso pubblico',
    'Disable public access' => 'Disabilita l\'accesso pubblico',
    'Enable public access' => 'Abilita l\'accesso pubblico',
    'Public access disabled' => 'Accesso pubblico disattivato',
    'Move the task to another project' => 'Sposta il compito in un altro progetto',
    'Move to project' => 'Sposta in un altro progetto',
    'Do you really want to duplicate this task?' => 'Vuoi davvero duplicare questo compito?',
    'Duplicate a task' => 'Duplica il compito',
    'External accounts' => 'Account esterni',
    'Account type' => 'Tipo di account',
    'Local' => 'Locale',
    'Remote' => 'Remoto',
    'Enabled' => 'Abilitato',
    'Disabled' => 'Disabilitato',
    'Login:' => 'Nome utente:',
    'Full Name:' => 'Nome:',
    'Email:' => 'Email:',
    'Notifications:' => 'Notifiche:',
    'Notifications' => 'Notifiche',
    'Account type:' => 'Tipo di account',
    'Edit profile' => 'Modifica profilo',
    'Change password' => 'Cambia password',
    'Password modification' => 'Modifica della password',
    'External authentications' => 'Autenticazione esterna',
    'Never connected.' => 'Mai connesso.',
    'No external authentication enabled.' => 'Nessuna autenticazione esterna abilitata.',
    'Password modified successfully.' => 'Password modificata con successo.',
    'Unable to change the password.' => 'Impossibile cambiare la password.',
    'Change category' => 'Cambia categoria',
    '%s updated the task %s' => '%s ha aggiornato il compito %s',
    '%s opened the task %s' => '%s ha aperto il compito %s',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s ha spostato il compito %s nella posizione #%d della colonna "%s"',
    '%s moved the task %s to the column "%s"' => '%s ha spostato il compito %s nella colonna "%s"',
    '%s created the task %s' => '%s ha creato il compito %s',
    '%s closed the task %s' => '%s ha chiuso il compito %s',
    '%s created a subtask for the task %s' => '%s ha creato un sotto-compito per il compito %s',
    '%s updated a subtask for the task %s' => '%s ha aggiornato un sotto-compito per il compito %s',
    'Assigned to %s with an estimate of %s/%sh' => 'Assegnato a %s con una stima di %s/%sh',
    'Not assigned, estimate of %sh' => 'Non assegnato, stima %sh',
    '%s updated a comment on the task %s' => '%s ha aggiornato un commento nel compito %s',
    '%s commented the task %s' => '%s ha commentato il compito %s',
    '%s\'s activity' => 'Attività di %s',
    'RSS feed' => 'Feed RSS',
    '%s updated a comment on the task #%d' => '%s ha aggiornato un commento del compito #%d',
    '%s commented on the task #%d' => '%s ha commentato il compito #%d',
    '%s updated a subtask for the task #%d' => '%s ha aggiornato un sotto-compito del compito #%d',
    '%s created a subtask for the task #%d' => '%s ha creato un sotto-compito del compito #%d',
    '%s updated the task #%d' => '%s ha aggiornato il compito #%d',
    '%s created the task #%d' => '%s ha creato il compito #%d',
    '%s closed the task #%d' => '%s ha chiuso il compito #%d',
    '%s opened the task #%d' => '%s ha aperto il compito #%d',
    'Activity' => 'Attività',
    'Default values are "%s"' => 'Valori di default "%s"',
    'Default columns for new projects (Comma-separated)' => 'Colonne di default per i nuovi progetti (Separati da virgola)',
    'Task assignee change' => 'Cambia l\'assegnatario del compito',
    '%s changed the assignee of the task #%d to %s' => '%s dai l\'assegnazione del compito #%d a %s',
    '%s changed the assignee of the task %s to %s' => '%s ha cambiato l\'assegnatario del compito %s a %s',
    'New password for the user "%s"' => 'Nuova password per l\'utente "%s"',
    'Choose an event' => 'Scegli un evento',
    'Create a task from an external provider' => 'Crea un compito da un provider esterno',
    'Change the assignee based on an external username' => 'Cambia l\'assegnatario basandosi su un username esterno',
    'Change the category based on an external label' => 'Cambia la categoria basandosi su un\'etichetta esterna',
    'Reference' => 'Riferimento',
    'Label' => 'Etichetta',
    'Database' => 'Database',
    'About' => 'Informazioni',
    'Database driver:' => 'Driver per Database',
    'Board settings' => 'Impostazioni bacheca',
    'Webhook settings' => 'Impostazione Webhook',
    'Reset token' => 'Rigenera il token',
    'API endpoint:' => 'Endpoint dell\'API:',
    'Refresh interval for personal board' => 'Intervallo di refresh per le bacheche private',
    'Refresh interval for public board' => 'Intervallo di refresh per le bacheche pubbliche',
    'Task highlight period' => 'Periodo di evidenza per il compito',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => 'Periodo (in secondi) per considerare un compito come modificato recentemente (0 per disabilitare, 2 giorni di default)',
    'Frequency in second (60 seconds by default)' => 'Frequenza in secondi (60 secondi di default)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => 'Frequenza in secondi (0 secondi di default)',
    'Application URL' => 'URL dell\'applicazione',
    'Token regenerated.' => 'Token rigenerato.',
    'Date format' => 'Formato data',
    'ISO format is always accepted, example: "%s" and "%s"' => 'Il formato ISO è sempre accettato, esempio: "%s" e "%s"',
    'New personal project' => 'Nuovo progetto privato',
    'This project is personal' => 'Questo progetto è privato',
    'Add' => 'Aggiungi',
    'Start date' => 'Data di inizio',
    'Time estimated' => 'Tempo stimato',
    'There is nothing assigned to you.' => 'Non c\'è nulla assegnato a te.',
    'My tasks' => 'I miei compiti',
    'Activity stream' => 'Flusso attività',
    'Dashboard' => 'Bacheca',
    'Confirmation' => 'Conferma',
    'Webhooks' => 'Webhooks',
    'API' => 'API',
    'Create a comment from an external provider' => 'Crea un commit da un provider esterno',
    'Project management' => 'Gestione progetti',
    'Columns' => 'Colonne',
    'Task' => 'Task',
    'Percentage' => 'Percentuale',
    'Number of tasks' => 'Numero di compiti',
    'Task distribution' => 'Distribuzione dei compiti',
    'Analytics' => 'Analitiche',
    'Subtask' => 'Sotto-compito',
    'User repartition' => 'Ripartizione per utente',
    'Clone this project' => 'Clona questo progetto',
    'Column removed successfully.' => 'Colonna rimossa con successo',
    'Not enough data to show the graph.' => 'Non ci sono abbastanza dati per visualizzare il grafico.',
    'Previous' => 'Precedente',
    'The id must be an integer' => 'L\'id deve essere un intero',
    'The project id must be an integer' => 'L\'id del progetto deve essere un intero',
    'The status must be an integer' => 'Lo status deve essere un intero',
    'The subtask id is required' => 'L\'id del sotto-compito è necessario',
    'The subtask id must be an integer' => 'L\'id del sotto-compito deve essere un intero',
    'The task id is required' => 'Richiesto l\'id del compito',
    'The task id must be an integer' => 'L\'id del compito deve essere un intero',
    'The user id must be an integer' => 'L\'id dell\'utente deve essere un intero',
    'This value is required' => 'Questo valore è necessario',
    'This value must be numeric' => 'Questo valore deve essere numerico',
    'Unable to create this task.' => 'Impossibile creare questo compito',
    'Cumulative flow diagram' => 'Diagramma di flusso cumulativo',
    'Daily project summary' => 'Sommario giornaliero del progetto',
    'Daily project summary export' => 'Export del sommario giornaliero del progetto',
    'Exports' => 'Esporta',
    'This export contains the number of tasks per column grouped per day.' => 'Questo export contiene il numero di compiti per colonna raggruppati per giorno',
    'Active swimlanes' => 'Corsie attive',
    'Add a new swimlane' => 'Aggiungi una corsia',
    'Default swimlane' => 'Corsia predefinita',
    'Do you really want to remove this swimlane: "%s"?' => 'Vuoi davvero rimuovere la seguente corsia: "%s"?',
    'Inactive swimlanes' => 'Corsie inattive',
    'Remove a swimlane' => 'Rimuovi una corsia',
    'Swimlane modification for the project "%s"' => 'Modifica corsia per il progetto "%s"',
    'Swimlane removed successfully.' => 'Corsia rimossa con successo.',
    'Swimlanes' => 'Corsie',
    'Swimlane updated successfully.' => 'Corsia aggiornata con successo.',
    'Unable to remove this swimlane.' => 'Impossibile rimuovere questa corsia.',
    'Unable to update this swimlane.' => 'Impossibile aggiornare questa corsia.',
    'Your swimlane has been created successfully.' => 'La tua corsia è stata creata con successo',
    'Example: "Bug, Feature Request, Improvement"' => 'Esempi: "Bug, Richiesta di Funzioni, Migliorie"',
    'Default categories for new projects (Comma-separated)' => 'Categorie di default per i progetti (Separati da virgola)',
    'Integrations' => 'Integrazioni',
    'Integration with third-party services' => 'Integrazione con servizi di terze parti',
    'Subtask Id' => 'Id del sotto-compito',
    'Subtasks' => 'Sotto-compiti',
    'Subtasks Export' => 'Esporta i sotto-compiti',
    'Task Title' => 'Titolo del compito',
    'Untitled' => 'Senza titolo',
    'Application default' => 'Default dell\'applicazione',
    'Language:' => 'Lingua',
    'Timezone:' => 'Fuso Orario',
    'All columns' => 'Tutte le colonne',
    'Next' => 'Prossimo',
    '#%d' => '#%d',
    'All swimlanes' => 'Tutte le corsie',
    'All colors' => 'Tutti i colori',
    'Moved to column %s' => 'Spostato sulla colonna "%s"',
    'User dashboard' => 'Bacheca utente',
    'Allow only one subtask in progress at the same time for a user' => 'Permetti un solo sotto-compito in corso per utente alla volta',
    'Edit column "%s"' => 'Modifica la colonna "%s"',
    'Select the new status of the subtask: "%s"' => 'Seleziona il nuovo status per il sotto-compito: "%s"',
    'Subtask timesheet' => 'Timesheet del sotto-compito',
    'There is nothing to show.' => 'Nulla da mostrare.',
    'Time Tracking' => 'Monitoraggio delle tempistiche',
    'You already have one subtask in progress' => 'Hai già un sotto-compito in corso',
    'Which parts of the project do you want to duplicate?' => 'Quali parti del progetto vuoi duplicare?',
    'Disallow login form' => 'Disabilita il form di login',
    'Start' => 'Inizio',
    'End' => 'Fine',
    'Task age in days' => 'Anzianità del compito in giorni',
    'Days in this column' => 'Giorni in questa colonna',
    '%dd' => '%dg',
    'Add a new link' => 'Aggiungi una nuova relazione',
    'Do you really want to remove this link: "%s"?' => 'Vuoi davvero rimuovere la seguente relazione: "%s"?',
    'Do you really want to remove this link with task #%d?' => 'Vuoi davvero rimuovere questa relazione dal compito #%d?',
    'Field required' => 'Campo necessario',
    'Link added successfully.' => 'Relazione aggiunta con successo.',
    'Link updated successfully.' => 'Relazione aggiornata con successo.',
    'Link removed successfully.' => 'Relazione rimossa con successo.',
    'Link labels' => 'Etichette delle relazioni',
    'Link modification' => 'Modifica relazione',
    'Opposite label' => 'Etichetta contraria',
    'Remove a link' => 'Rimuovi una relazione',
    'The labels must be different' => 'Le etichette devono essere diverse',
    'There is no link.' => 'Nessuna relazione presente.',
    'This label must be unique' => 'Questa etichetta deve essere univoca',
    'Unable to create your link.' => 'Impossibile creare la relazione.',
    'Unable to update your link.' => 'Impossibile aggiornare la relazione.',
    'Unable to remove this link.' => 'Impossibile rimuovere la relazione.',
    'relates to' => 'si riferisce a',
    'blocks' => 'blocca',
    'is blocked by' => 'è bloccato da',
    'duplicates' => 'duplica',
    'is duplicated by' => 'è duplicato da',
    'is a child of' => 'è un figlio di',
    'is a parent of' => 'è un genitore di',
    'targets milestone' => 'punta alla milestone',
    'is a milestone of' => 'è una milestone di',
    'fixes' => 'sistema',
    'is fixed by' => 'è sistemato da',
    'This task' => 'Questo compito',
    '<1h' => '<1h',
    '%dh' => '%dh',
    'Expand tasks' => 'Espandi i compiti',
    'Collapse tasks' => 'Minimizza i compiti',
    'Expand/collapse tasks' => 'Espandi/minimizza i compiti',
    'Close dialog box' => 'Chiudi la finestra di dialogo',
    'Submit a form' => 'Invia i dati',
    'Board view' => 'Vista bacheca',
    'Keyboard shortcuts' => 'Scorciatoie da tastiera',
    'Open board switcher' => 'Apri il selettore di bacheche',
    'Application' => 'Applicazione',
    'Compact view' => 'Vista compatta',
    'Horizontal scrolling' => 'Scrolling orizzontale',
    'Compact/wide view' => 'Vista compatta/estesa',
    'Currency' => 'Valuta',
    'Personal project' => 'Progetto privato',
    'AUD - Australian Dollar' => 'AUD - Dollari Australiani',
    'CAD - Canadian Dollar' => 'CAD - Dollari Canadesi',
    'CHF - Swiss Francs' => 'CHF - Franchi Svizzeri',
    'Custom Stylesheet' => 'Foglio di stile personalizzato',
    'EUR - Euro' => 'EUR - Euro',
    'GBP - British Pound' => 'GBP - Pound Inglesi',
    'INR - Indian Rupee' => 'INR - Rupie Indiani',
    'JPY - Japanese Yen' => 'JPY - Yen Giapponesi',
    'NZD - New Zealand Dollar' => 'NZD - Dollari della Nuova Zelanda',
    'PEN - Peruvian Sol' => 'PEN - Sol peruviano',
    'RSD - Serbian dinar' => 'RSD - Dinar serbo',
    'CNY - Chinese Yuan' => 'CNY - Yuan cinese',
    'USD - US Dollar' => 'USD - Dollari Americani',
    'VES - Venezuelan Bolívar' => 'VES - Bolívar venezuelano',
    'Destination column' => 'Colonna destinazione',
    'Move the task to another column when assigned to a user' => 'Sposta il compito in un\'altra colonna quando viene assegnato ad un utente',
    'Move the task to another column when assignee is cleared' => 'Sposta il compito in un\'altra colonna quando l\'assegnatario viene cancellato',
    'Source column' => 'Colonna sorgente',
    'Transitions' => 'Transizioni',
    'Executer' => 'Esecutore',
    'Time spent in the column' => 'Tempo trascorso nella colonna',
    'Task transitions' => 'Transizioni dei compiti',
    'Task transitions export' => 'Export delle transizioni dei compiti',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => 'Questo report contiene tutti gli spotamenti di colonna per ogni compito con le date, l\'utente ed il tempo trascorso per ogni transizione',
    'Currency rates' => 'Tassi di cambio',
    'Rate' => 'Cambio',
    'Change reference currency' => 'Cambia la valuta di riferimento',
    'Reference currency' => 'Valuta di riferimento',
    'The currency rate has been added successfully.' => 'Il tasso di cambio è stato aggiunto con successo.',
    'Unable to add this currency rate.' => 'Impossibile aggiungere questo tasso di cambio.',
    'Webhook URL' => 'URL Webhook',
    '%s removed the assignee of the task %s' => '%s rimuove l\'assegnatario del compito %s',
    'Information' => 'Informazioni',
    'Check two factor authentication code' => 'Controlla il codice di autenticazione "two-factor"',
    'The two factor authentication code is not valid.' => 'Il codice di autenticazione "two-factor" non è valido',
    'The two factor authentication code is valid.' => 'Il codice di autenticazione "two-factor" è valido',
    'Code' => 'Codice',
    'Two factor authentication' => 'Autenticazione "two-factor"',
    'This QR code contains the key URI: ' => 'Questo QR code contiene l\'URI: ',
    'Check my code' => 'Controlla il mio codice',
    'Secret key: ' => 'Chiave privata:',
    'Test your device' => 'Testa il tuo dispositivo',
    'Assign a color when the task is moved to a specific column' => 'Assegna un colore quando il compito viene spostato in una colonna specifica',
    '%s via Kanboard' => '%s tramite Kanboard',
    'Burndown chart' => 'Grafico Burndown',
    'This chart show the task complexity over the time (Work Remaining).' => 'Questo grafico mostra la complessità dei compiti nel tempo (Lavoro residuo).',
    'Screenshot taken %s' => 'Schermata catturata %s',
    'Add a screenshot' => 'Aggiungi una schermata',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => 'Cattura una schermata e premi CTRL+V o ⌘+V per incollarla qui.',
    'Screenshot uploaded successfully.' => 'Schermata caricata con successo.',
    'SEK - Swedish Krona' => 'SEK - Corona svedese',
    'Identifier' => 'Identificatore',
    'Disable two factor authentication' => 'Disabilita l\'autenticazione "two-factor"',
    'Do you really want to disable the two factor authentication for this user: "%s"?' => 'Vuoi davvero disabilitare l\'autenticazione "two-factor" per questo utente: "%s"?',
    'Edit link' => 'Modifica relazione',
    'Start to type task title...' => 'Inzia a digitare il titolo di un compito...',
    'A task cannot be linked to itself' => 'Un compito non può essere correlato a se stesso',
    'The exact same link already exists' => 'La stessa relazione risulta già esistente',
    'Recurrent task is scheduled to be generated' => 'Il compito ricorrente è pianificato per essere generato',
    'Score' => 'Punteggio',
    'The identifier must be unique' => 'L\'identificatore deve essere univoco',
    'This linked task id doesn\'t exists' => 'L\'id del compito correlato non esiste',
    'This value must be alphanumeric' => 'Questo valore deve essere alfanumerico',
    'Edit recurrence' => 'Modifica ricorrenza',
    'Generate recurrent task' => 'Genera compito ricorrente',
    'Trigger to generate recurrent task' => 'Trigger per generare il compito ricorrente',
    'Factor to calculate new due date' => 'Fattore numerico per calcolare la nuova data di scadenza',
    'Timeframe to calculate new due date' => 'Lasso temporale per calcolare la nuova data di scadenza',
    'Base date to calculate new due date' => 'Data di partenza per calcolare la nuova data di scadenza',
    'Action date' => 'Data di azione (action date)',
    'Base date to calculate new due date: ' => 'Data di base per calcolare la nuova data di scadenza: ',
    'This task has created this child task: ' => 'Questo compito ha creato il seguente compito figlio: ',
    'Day(s)' => 'Giorno/i',
    'Existing due date' => 'Data di scadenza esistente',
    'Factor to calculate new due date: ' => 'Fattore numerico per calcolare la nuova data di scadenza: ',
    'Month(s)' => 'Mese/i',
    'This task has been created by: ' => 'Questo compito è stato creato da: ',
    'Recurrent task has been generated:' => 'Il compito ricorrente è stato generato:',
    'Timeframe to calculate new due date: ' => 'Lasso temporale per calcolare la nuova data di scadenza: ',
    'Trigger to generate recurrent task: ' => 'Trigger per generare il compito ricorrente: ',
    'When task is closed' => 'Quando un compito è chiuso',
    'When task is moved from first column' => 'Quando un compito è spostato dalla prima colonna',
    'When task is moved to last column' => 'Quando un compito è spostato nell\'ultima colonna',
    'Year(s)' => 'Anno/i',
    'Project settings' => 'Impostazioni di progetto',
    'Automatically update the start date' => 'Aggiorna automaticamente la data di inizio',
    'iCal feed' => 'feed iCal',
    'Preferences' => 'Preferenze',
    'Security' => 'Sicurezza',
    'Two factor authentication disabled' => 'Two factor authentication disabilitata',
    'Two factor authentication enabled' => 'Two factor authentication abilitata',
    'Unable to update this user.' => 'Impossibile aggiornare questo utente.',
    'There is no user management for personal projects.' => 'Non è prevista la gestione di utenti per i progetti privati.',
    'User that will receive the email' => 'Utente che riceverà l\'email',
    'Email subject' => 'Soggetto dell\'email',
    'Date' => 'Data',
    'Add a comment log when moving the task between columns' => 'Aggiungi un log quando si sposta un compito tra colonne',
    'Move the task to another column when the category is changed' => 'Sposta il compito in un\'altra colonna quando la categoria viene modificata',
    'Send a task by email to someone' => 'Invia un compito via email a qualcuno',
    'Reopen a task' => 'Riapri un compito',
    'Notification' => 'Notifica',
    '%s moved the task #%d to the first swimlane' => '%s ha spostato il compito #%d nella prima corsia',
    'Swimlane' => 'Corsia',
    '%s moved the task %s to the first swimlane' => '%s ha spostato il compito %s nella prima corsia',
    '%s moved the task %s to the swimlane "%s"' => '%s ha spostato il compito %s nella corsia %s',
    'This report contains all subtasks information for the given date range.' => 'Questo report contiente tutte le informazioni sui sotto-compiti nell\'arco temporale indicato.',
    'This report contains all tasks information for the given date range.' => 'Questo report contiente tutte le informazioni sui compiti nell\'arco temporale indicato.',
    'Project activities for %s' => 'Attività di progetto per %s',
    'view the board on Kanboard' => 'guarda la bacheca su Kanboard',
    'The task has been moved to the first swimlane' => 'Il compito è stato spostato nella prima corsia',
    'The task has been moved to another swimlane:' => 'Il compito è stato spostato in un\'altra corsia:',
    'New title: %s' => 'Nuovo titolo: %s',
    'The task is not assigned anymore' => 'Il compito non è più assegnato a nessuno',
    'New assignee: %s' => 'Nuovo assegnatario: %s',
    'There is no category now' => 'Non è presente più nessuna categoria',
    'New category: %s' => 'Nuova categoria: %s',
    'New color: %s' => 'Nuovo colore: %s',
    'New complexity: %d' => 'Nuova complessità: %d',
    'The due date has been removed' => 'La data di scadenza è stata rimossa',
    'There is no description anymore' => 'Non è presente più alcuna descrizione.',
    'Recurrence settings has been modified' => 'Le impostazioni di ricorrenza sono state modificate',
    'Time spent changed: %sh' => 'Tempo trascorso modificato: %sh',
    'Time estimated changed: %sh' => 'Tempo stimato modificato: %sh',
    'The field "%s" has been updated' => 'Il campo %s è stato aggiornato',
    'The description has been modified:' => 'La descrizione è stata modificata',
    'Do you really want to close the task "%s" as well as all subtasks?' => 'Vuoi veramente chiudere il compito "%s" e i relativi sotto-compiti?',
    'I want to receive notifications for:' => 'Voglio ricevere le notifiche per:',
    'All tasks' => 'Tutti i compiti',
    'Only for tasks assigned to me' => 'Solo per i compiti assegnati a me',
    'Only for tasks created by me' => 'Solo per i compiti creati da me',
    'Only for tasks created by me and tasks assigned to me' => 'Solo per i compiti creati da me o assegnati a me',
    '%%Y-%%m-%%d' => '%%Y-%%m-%%d',
    'Total for all columns' => 'Totale per tutte le colonne',
    'You need at least 2 days of data to show the chart.' => 'Hai bisogno di almeno 2 giorni di dati per mostrare il grafico.',
    '<15m' => '<15m',
    '<30m' => '<30m',
    'Stop timer' => 'Ferma il timer',
    'Start timer' => 'Avvia il timer',
    'My activity stream' => 'Il mio flusso attività',
    'Search tasks' => 'Ricerca compiti',
    'Reset filters' => 'Annulla filtri',
    'My tasks due tomorrow' => 'I miei compiti da completare per domani',
    'Tasks due today' => 'Task da completare oggi',
    'Tasks due tomorrow' => 'Task da completare per domani',
    'Tasks due yesterday' => 'Task da completare ieri',
    'Closed tasks' => 'Task chiusi',
    'Open tasks' => 'Task aperti',
    'Not assigned' => 'Non assegnato',
    'View advanced search syntax' => 'Visualizza la sintassi di ricerca avanzata',
    'Overview' => 'Panoramica',
    'Board/Calendar/List view' => 'Vista Bacheca/Calendario/Lista',
    'Switch to the board view' => 'Passa alla vista "bacheca"',
    'Switch to the list view' => 'Passa alla vista "elenco"',
    'Go to the search/filter box' => 'Vai alla casella di ricerca/filtro',
    'There is no activity yet.' => 'Non è presente ancora nessuna attività.',
    'No tasks found.' => 'Nessun compito trovato.',
    'Keyboard shortcut: "%s"' => 'Scorciatoia da tastiera: "%s"',
    'List' => 'Lista',
    'Filter' => 'Filtro',
    'Advanced search' => 'Ricerca avanzata',
    'Example of query: ' => 'Esempio di query: ',
    'Search by project: ' => 'Ricerca per progetto: ',
    'Search by column: ' => 'Ricerca per colonna: ',
    'Search by assignee: ' => 'Ricerca per assegnatario: ',
    'Search by color: ' => 'Ricerca per colore: ',
    'Search by category: ' => 'Ricerca per categoria: ',
    'Search by description: ' => 'Ricerca per descrizione: ',
    'Search by due date: ' => 'Ricerca per data di scadenza: ',
    'Average time spent in each column' => 'Tempo medio trascorso in ogni colonna',
    'Average time spent' => 'Tempo medio trascorso',
    'This chart shows the average time spent in each column for the last %d tasks.' => 'Questo grafico mostra il tempo medio trascorso in ogni colonna per gli ultimi %d compiti.',
    'Average Lead and Cycle time' => 'Tempo medio di consegna (Lead Time) e lavorazione (Cycle Time)',
    'Average lead time: ' => 'Tempo medio di consegna (Lead Time): ',
    'Average cycle time: ' => 'Tempo medio di lavorazione (Cycle Time): ',
    'Cycle Time' => 'Tempo di lavorazione (Cycle Time)',
    'Lead Time' => 'Tempo di consegna (Lead Time)',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => 'Questo grafico mostra i tempi medi di consegna (Lead Time) e lavorazione (Cycle Time) per gli ultimi %d compiti.',
    'Average time into each column' => 'Tempo medio in ogni colonna',
    'Lead and cycle time' => 'Tempo di consegna e lavorazione',
    'Lead time: ' => 'Tempo di consegna (Lead Time): ',
    'Cycle time: ' => 'Tempo di lavorazione (Cycle Time): ',
    'Time spent in each column' => 'Tempo trascorso in ogni colonna',
    'The lead time is the duration between the task creation and the completion.' => 'Il tempo di consegna (Lead Time) è la durata tra la creazione di un compito ed il suo completamento.',
    'The cycle time is the duration between the start date and the completion.' => 'Il tempo di lavorazione (Cycle Time) è la durata tra la data di inizio della lavorazione di un compito ed il suo completamento.',
    'If the task is not closed the current time is used instead of the completion date.' => 'Se il compito non è chiuso sarà usata la data attuale invece della data di completamento.',
    'Set the start date automatically' => 'Imposta automaticamente la data di inizio',
    'Edit Authentication' => 'Modifica Autenticazione',
    'Remote user' => 'Utente remoto',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => 'La password degli utenti remoti (ad esempio: LDAP, account Google e Github) non è salvata nel database di Kanboard',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => 'Se selezioni la casella "Disabilita il form di login", le credenziali immesse nel modulo di accesso verranno ignorate.',
    'Default task color' => 'Colore predefinito dei compiti',
    'This feature does not work with all browsers.' => 'Questa feature non funziona con tutti i browser.',
    'There is no destination project available.' => 'Non ci sono progetti disponbili come destinazione.',
    'Trigger automatically subtask time tracking' => 'Attiva automaticamente il time-tracking per i sotto-compiti',
    'Include closed tasks in the cumulative flow diagram' => 'Includi i compiti chiusi nel diagramma di flusso cumulativo',
    'Current swimlane: %s' => 'Corsia attuale: %s',
    'Current column: %s' => 'Colonna attuale: %s',
    'Current category: %s' => 'Categoria attuale: %s',
    'no category' => 'nessuna categoria',
    'Current assignee: %s' => 'Assegnatario attuale: %s',
    'not assigned' => 'non assegnato',
    'Author:' => 'Autore',
    'contributors' => 'contributori',
    'License:' => 'Licenza:',
    'License' => 'Licenza',
    'Enter the text below' => 'Inserisci il testo qui sotto',
    'Start date:' => 'Data di inizio:',
    'Due date:' => 'Data di completamento:',
    'People who are project managers' => 'Persone che sono manager di progetto',
    'People who are project members' => 'Persone che sono membri di progetto',
    'NOK - Norwegian Krone' => 'NOK - Corone norvegesi',
    'Show this column' => 'Mostra questa colonna',
    'Hide this column' => 'Nascondi questa colonna',
    'End date' => 'Data di fine',
    'Users overview' => 'Panoramica utenti',
    'Members' => 'Membri',
    'Shared project' => 'Progetto condiviso',
    'Project managers' => 'Manager di progetto',
    'Projects list' => 'Elenco progetti',
    'End date:' => 'Data di fine:',
    'Change task color when using a specific task link' => 'Cambia colore del compito quando si un utilizza una determinata relazione di compito',
    'Task link creation or modification' => 'Creazione o modifica di relazione di compito',
    'Milestone' => 'Milestone',
    'Reset the search/filter box' => 'Resetta la riceca/filtro',
    'Documentation' => 'Documentazione',
    'Author' => 'Autore',
    'Version' => 'Versione',
    'Plugins' => 'Plugin',
    'There is no plugin loaded.' => 'Nessun plugin è stato caricato.',
    'My notifications' => 'Le mie notifiche',
    'Custom filters' => 'Filtri personalizzati',
    'Your custom filter has been created successfully.' => 'Il filtro personalizzato è stato creato con successo.',
    'Unable to create your custom filter.' => 'Impossibile creare il filtro personalizzato.',
    'Custom filter removed successfully.' => 'Filtro personalizzato rimosso con successo.',
    'Unable to remove this custom filter.' => 'Impossibile rimuovere questo filtro personalizzato',
    'Edit custom filter' => 'Modifica il filtro personalizzato',
    'Your custom filter has been updated successfully.' => 'Il filtro personalizzato è stato aggiornato con successo.',
    'Unable to update custom filter.' => 'Impossibile aggiornare il filtro personalizzato.',
    'Web' => 'Web',
    'New attachment on task #%d: %s' => 'Nuovo allegato nel compito #%d: %s',
    'New comment on task #%d' => 'Nuovo commento nel compito #%d',
    'Comment updated on task #%d' => 'Commento aggiornato nel compito #%d',
    'New subtask on task #%d' => 'Nuovo sotto-compito nel compito #%d',
    'Subtask updated on task #%d' => 'Sotto-compito aggiornato nel compito #%d',
    'New task #%d: %s' => 'Nuovo compito #%d: %s',
    'Task updated #%d' => 'Task #%d aggiornato',
    'Task #%d closed' => 'Task #%d chiuso',
    'Task #%d opened' => 'Task #%d aperto',
    'Column changed for task #%d' => 'Colonna modificata per il compito #%d',
    'New position for task #%d' => 'Nuova posizione per il compito #%d',
    'Swimlane changed for task #%d' => 'Corsia modificata per il compito #%d',
    'Assignee changed on task #%d' => 'Assegnatario modificato per il compito #%d',
    '%d overdue tasks' => '%d compiti scaduti',
    'No notification.' => 'Nessuna nuova notifica.',
    'Mark all as read' => 'Segna tutti come letti',
    'Mark as read' => 'Segna come letto',
    'Total number of tasks in this column across all swimlanes' => 'Numero totale di compito in questa colonna per tutte le corsie',
    'Collapse swimlane' => 'Minimizza corsia',
    'Expand swimlane' => 'Espandi corsia',
    'Add a new filter' => 'Aggiungi un nuovo filtro',
    'Share with all project members' => 'Condividi con tutti i membri del progetto',
    'Shared' => 'Condiviso',
    'Owner' => 'Proprietario',
    'Unread notifications' => 'Notifiche non lette',
    'Notification methods:' => 'Metodi di notifica',
    'Unable to read your file' => 'Impossibile leggere il file',
    '%d task(s) have been imported successfully.' => '%d compito/i sono stati importati con successo.',
    'Nothing has been imported!' => 'Non è stato importato nulla!',
    'Import users from CSV file' => 'Importa utenti da file CSV',
    '%d user(s) have been imported successfully.' => '%d utenti importati con successo.',
    'Comma' => 'Virgola',
    'Semi-colon' => 'Punto e virgola',
    'Tab' => 'Tabulazione',
    'Vertical bar' => 'Barra verticale',
    'Double Quote' => 'Apice singolo',
    'Single Quote' => 'Doppio apice',
    '%s attached a file to the task #%d' => '%s ha allegato un file al compito #%d',
    'There is no column or swimlane activated in your project!' => 'Non ci sono colonne o corsie attive all\'interno del tuo progetto!',
    'Append filter (instead of replacement)' => 'Aggiungi filtro (anzichè sostituirlo)',
    'Append/Replace' => 'Aggiungi/Sostituisci',
    'Append' => 'Aggiungi',
    'Replace' => 'Sostituisci',
    'Import' => 'Importa',
    'Change sorting' => 'cambia ordinamento',
    'Tasks Importation' => 'Importazione compito',
    'Delimiter' => 'Delimitatore',
    'Enclosure' => 'Contenitore',
    'CSV File' => 'File CSV',
    'Instructions' => 'Istruzioni',
    'Your file must use the predefined CSV format' => 'Il file deve rispettare il formato CSV predefinito',
    'Your file must be encoded in UTF-8' => 'Il file deve essere codificato in formato UTF-8',
    'The first row must be the header' => 'La prima riga deve contenere l\'intestazione',
    'Duplicates are not verified for you' => 'Le righe duplicate non verranno controllate',
    'The due date must use the ISO format: YYYY-MM-DD' => 'La data di scadenza deve usare il formato ISO: YYYY-MM-DD',
    'Download CSV template' => 'Scarica il template CSV',
    'No external integration registered.' => 'Nessuna integrazione esterna presente.',
    'Duplicates are not imported' => 'I duplicati non veranno importati',
    'Usernames must be lowercase and unique' => 'I nomi utente devono essere in minuscolo e univoci',
    'Passwords will be encrypted if present' => 'Se presenti, le password verranno criptate',
    '%s attached a new file to the task %s' => '%s ha allegato un nuovo file al compito %s',
    'Link type' => 'Tipo di link',
    'Assign automatically a category based on a link' => 'Assegna automaticamente una categoria sulla base di una relazione',
    'BAM - Konvertible Mark' => 'BAM - Marco bosniaco',
    'Assignee Username' => 'Nome utente dell\'assegnatario',
    'Assignee Name' => 'Nome dell\'assegnatario',
    'Groups' => 'Gruppi',
    'Members of %s' => 'Membri di %s',
    'New group' => 'Nuovo gruppo',
    'Group created successfully.' => 'Gruppo creato con successo',
    'Unable to create your group.' => 'Impossibile creare il gruppo',
    'Edit group' => 'Modifica gruppo',
    'Group updated successfully.' => 'Gruppo aggiornato con successo.',
    'Unable to update your group.' => 'Impossibile aggiornare il gruppo',
    'Add group member to "%s"' => 'Aggiungi un membro al gruppo "%s"',
    'Group member added successfully.' => 'Membro del gruppo aggiunto con successo.',
    'Unable to add group member.' => 'Impossibile aggiungere un membro del gruppo',
    'Remove user from group "%s"' => 'Rimuovi utente dal gruppo "%s"',
    'User removed successfully from this group.' => 'Utente rimosso dal gruppo con successo.',
    'Unable to remove this user from the group.' => 'Impossibile rimuovere l\'utentei dal gruppo.',
    'Remove group' => 'Rimuovi gruppo',
    'Group removed successfully.' => 'Gruppo rimosso con successo.',
    'Unable to remove this group.' => 'Impossibile rimuovere questo gruppo.',
    'Project Permissions' => 'Permessi del progetto',
    'Manager' => 'Manager',
    'Project Manager' => 'Manager del progetto',
    'Project Member' => 'Membro del progetto',
    'Project Viewer' => 'Osservatore del progetto',
    'Your account is locked for %d minutes' => 'Il tuo account è bloccato per %d minuti',
    'Invalid captcha' => 'Captcha non valido',
    'The name must be unique' => 'Il nome deve essere univoco',
    'View all groups' => 'Visualiza tutti i gruppi',
    'There is no user available.' => 'Nessun utente disponibile.',
    'Do you really want to remove the user "%s" from the group "%s"?' => 'Vuoi davvero rimuovere l\'utente "%s" dal gruppo "%s"?',
    'There is no group.' => 'Nessun gruppo presente',
    'Add group member' => 'Aggiungi un membro del gruppo',
    'Do you really want to remove this group: "%s"?' => 'Vuoi davvero rimuovere questo gruppo: "%s"?',
    'There is no user in this group.' => 'Nessun utente in questo gruppo.',
    'Permissions' => 'Permessi',
    'Allowed Users' => 'Utenti autorizzati',
    'No specific user has been allowed.' => 'Nessun utente è stato esplicitamente autorizzato.',
    'Role' => 'Ruolo',
    'Enter user name...' => 'Inserisci il nome utente...',
    'Allowed Groups' => 'Gruppi autorizzati',
    'No group has been allowed.' => 'Nessun gruppo è stato esplicitamente autorizzato.',
    'Group' => 'Gruppo',
    'Group Name' => 'Nome del gruppo',
    'Enter group name...' => 'Inserisci il nome del gruppo...',
    'Role:' => 'Ruolo:',
    'Project members' => 'Membri di progetto',
    '%s mentioned you in the task #%d' => '%s ti ha menzionato nel compito #%d',
    '%s mentioned you in a comment on the task #%d' => '%s ti ha menzionato in un commento del compito #%d',
    'You were mentioned in the task #%d' => 'Sei stato menzionato nel compito #%d',
    'You were mentioned in a comment on the task #%d' => 'Sei stato menzionato in un commento del compito #%d',
    'Estimated hours: ' => 'Ore stimate: ',
    'Actual hours: ' => 'Ore effettive: ',
    'Hours Spent' => 'Ore impiegate',
    'Hours Estimated' => 'Ore stimate',
    'Estimated Time' => 'Tempo stimato',
    'Actual Time' => 'Tempo effettivo',
    'Estimated vs actual time' => 'Tempo stimato vs Tempo effettivo',
    'RUB - Russian Ruble' => 'RUB - Rublo russo',
    'Assign the task to the person who does the action when the column is changed' => 'Assegna il compito alla persona che esegue l\'azione quando la colonna viene modificata',
    'Close a task in a specific column' => 'Chiudi un compito in una specifica colonna',
    'Time-based One-time Password Algorithm' => 'Algoritmo per la Time-based One-time Password',
    'Two-Factor Provider: ' => 'Provider autenticazione a due fattori: ',
    'Disable two-factor authentication' => 'Disabilita l\'autenticazione "two-factor"',
    'Enable two-factor authentication' => 'Abilita l\'autenticazione "two-factor"',
    'There is no integration registered at the moment.' => 'Nessuna integrazione disponibile al momento.',
    'Password Reset for Kanboard' => 'Reimposta password per Kanboard',
    'Forgot password?' => 'Password dimenticata?',
    'Enable "Forget Password"' => 'Abilita funzione "Password dimenticata"',
    'Password Reset' => 'Reimposta password',
    'New password' => 'Nuova password',
    'Change Password' => 'Cambia password',
    'To reset your password click on this link:' => 'Per reimpostare la tua password clicca su questo link:',
    'Last Password Reset' => 'Ultimo cambio password',
    'The password has never been reinitialized.' => 'La password non è mai stata reimpostata.',
    'Creation' => 'Creazione',
    'Expiration' => 'Scadenza',
    'Password reset history' => 'Storico cambio password',
    'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Tutti i compiti della colonna "%s" e della corsia "%s" sono stati chiusi con successo.',
    'Do you really want to close all tasks of this column?' => 'Vuoi davvero chiudere tutti i compiti di questa colonna?',
    '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d compito/i della colonna "%s" e della corsia "%s" saranno chiusi.',
    'Close all tasks in this column and this swimlane' => 'Chiudi tutti i compiti di questa colonna',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Nessun plugin ha caricato un metodo di notifica di progetto. Puoi tuttavia configurare le notifiche personali dal tuo profilo utente.',
    'My dashboard' => 'La mia bacheca',
    'My profile' => 'Il mio profilo',
    'Project owner: ' => 'Proprietario del progetto: ',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => 'L\'identificativo del progetto è opzionale e deve essere alfanumerico, ad esempio: MIOPROGETTO.',
    'Project owner' => 'Proprietario del progetto',
    'Personal projects do not have users and groups management.' => 'Per i progetti privati non è prevista la gestione di utenti e gruppi.',
    'There is no project member.' => 'Non è impostato un membro del progetto.',
    'Priority' => 'Priorità',
    'Task priority' => 'Priorità del compito',
    'General' => 'Generale',
    'Dates' => 'Date',
    'Default priority' => 'Priorità predefinita',
    'Lowest priority' => 'Priorità minima',
    'Highest priority' => 'Priorità massima',
    'Close a task when there is no activity' => 'Chiudi un compito quando non c\'è nessuna attività',
    'Duration in days' => 'Durata in giorni',
    'Send email when there is no activity on a task' => 'Invia un\'email quando non c\'è attività sul compito',
    'Unable to fetch link information.' => 'Impossibile recuperare informazioni sul link.',
    'Daily background job for tasks' => 'Job giornaliero in background per i compiti',
    'Auto' => 'Automatico',
    'Related' => 'Correlato',
    'Attachment' => 'Allegato',
    'Web Link' => 'Link Web',
    'External links' => 'Link esterni',
    'Add external link' => 'Aggiungi link esterno',
    'Type' => 'Tipo',
    'Dependency' => 'Dipendenza',
    'Add internal link' => 'Aggiungi link interno',
    'Add a new external link' => 'Aggiungi un nuovo link esterno',
    'Edit external link' => 'Modifica link esterno',
    'External link' => 'Link esterno',
    'Copy and paste your link here...' => 'Copia e incolla il tuo link qui...',
    'URL' => 'URL',
    'Internal links' => 'Link interni',
    'Assign to me' => 'Assegna a me',
    'Me' => 'Me stesso',
    'Do not duplicate anything' => 'Non duplicare nulla',
    'Projects management' => 'Gestione progetti',
    'Users management' => 'Gestione utenti',
    'Groups management' => 'Gestione gruppi',
    'Create from another project' => 'Crea da un\'altro progetto',
    'open' => 'aperto',
    'closed' => 'chiuso',
    'Priority:' => 'Priorità:',
    'Reference:' => 'Riferimento:',
    'Complexity:' => 'Complessità:',
    'Swimlane:' => 'Corsia:',
    'Column:' => 'Colonna:',
    'Position:' => 'Posizione:',
    'Creator:' => 'Creatore:',
    'Time estimated:' => 'Tempo stimato:',
    '%s hours' => '%s ore',
    'Time spent:' => 'Tempo trascorso:',
    'Created:' => 'Creato:',
    'Modified:' => 'Modificato:',
    'Completed:' => 'Completato:',
    'Started:' => 'Iniziato:',
    'Moved:' => 'Spostato:',
    'Task #%d' => 'Task #%d',
    'Time format' => 'Formato ora',
    'Start date: ' => 'Data di inizio: ',
    'End date: ' => 'Data di fine: ',
    'New due date: ' => 'Nuova data di scadenza: ',
    'Start date changed: ' => 'Data di inizio cambiata: ',
    'Disable personal projects' => 'Disabilita progetti privati',
    'Do you really want to remove this custom filter: "%s"?' => 'Vuoi davvero rimuovere questo filtro personalizato: "%s"?',
    'Remove a custom filter' => 'Rimuovi un filtro personalizzato',
    'User activated successfully.' => 'Utente attivato con successo.',
    'Unable to enable this user.' => 'Impossibile abilitare questo utente.',
    'User disabled successfully.' => 'Utente disabilitato con successo.',
    'Unable to disable this user.' => 'Impossibile disabilitare questo utente.',
    'All files have been uploaded successfully.' => 'Tutti i file sono stati caricati con successo.',
    'The maximum allowed file size is %sB.' => 'La dimensione massima consentita del file è %sB.',
    'Drag and drop your files here' => 'Trascina i tuoi file qui',
    'choose files' => 'seleziona i file',
    'View profile' => 'Guarda il profilo',
    'Two Factor' => 'Due fattori',
    'Disable user' => 'Disabilita utente',
    'Do you really want to disable this user: "%s"?' => 'Vuoi davvero disabilitare questo utente: "%s"?',
    'Enable user' => 'Abilita utente',
    'Do you really want to enable this user: "%s"?' => 'Vuoi davvero abilitare questo utente: "%s"?',
    'Download' => 'Scarica',
    'Uploaded: %s' => 'Caricato: %s',
    'Size: %s' => 'Dimensione: %s',
    'Uploaded by %s' => 'Caricato da %s',
    'Filename' => 'Nome del file',
    'Size' => 'Dimensione',
    'Column created successfully.' => 'Colonna creata con successo.',
    'Another column with the same name exists in the project' => 'Un\'altra colonna con lo stesso nome è già esistente in questo progetto',
    'Default filters' => 'Filtri predefiniti',
    'Your board doesn\'t have any columns!' => 'La tua bacheca non ha nessuna colonna!',
    'Change column position' => 'Modifica la posizione della colonna',
    'Switch to the project overview' => 'Passa alla panoramica di progetto',
    'User filters' => 'Filtri utente',
    'Category filters' => 'Filtri di categorie',
    'Upload a file' => 'Carica un file',
    'View file' => 'Visualizza file',
    'Last activity' => 'Attività recente',
    'Change subtask position' => 'Cambia la posizione del sotto-compito',
    'This value must be greater than %d' => 'Questo valore deve essere magiore di %d',
    'Another swimlane with the same name exists in the project' => 'Un\'altra corsia con lo stesso nome è già esistente in questo progetto',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => 'Esempio: https:example.kanboard.org/ (usato per generare URL assolute)',
    'Actions duplicated successfully.' => 'Azioni duplicate con successo.',
    'Unable to duplicate actions.' => 'Impossibile duplicare le azioni.',
    'Add a new action' => 'Aggiungi una nuova azione',
    'Import from another project' => 'Importa da un altro progetto',
    'There is no action at the moment.' => 'Nessuna azione disponibile al momento.',
    'Import actions from another project' => 'Importa azioni da un altro progetto',
    'There is no available project.' => 'Nessun progetto disponibile.',
    'Local File' => 'File locale',
    'Configuration' => 'Configurazione',
    'PHP version:' => 'Versione PHP:',
    'PHP SAPI:' => 'PHP SAPI:',
    'OS version:' => 'Versione OS:',
    'Database version:' => 'Versione database:',
    'Browser:' => 'Browser:',
    'Task view' => 'Vista dei compiti',
    'Edit task' => 'Modifica compito',
    'Edit description' => 'Modifica descrizione',
    'New internal link' => 'Nuovo link interno',
    'Display list of keyboard shortcuts' => 'Mostra una lista di scorciatoie da tastiera',
    'Avatar' => 'Avatar',
    'Upload my avatar image' => 'Carica l\'immagine del mio avatar',
    'Remove my image' => 'Rimuovi la mia immagine',
    'The OAuth2 state parameter is invalid' => 'Il parametro di stato OAuth2 non è valido.',
    'User not found.' => 'Utente non trovato.',
    'Search in activity stream' => 'Ricerca nel mio flusso attività',
    'My activities' => 'Le mie attività',
    'Activity until yesterday' => 'Attività ad oggi',
    'Activity until today' => 'Attività fino a ieri',
    'Search by creator: ' => 'Ricerca per creatore: ',
    'Search by creation date: ' => 'Ricerca per data di creazione: ',
    'Search by task status: ' => 'Ricerca per stato del compito: ',
    'Search by task title: ' => 'Ricerca per titolo del compito: ',
    'Activity stream search' => 'Ricerca nel flusso attività',
    'Projects where "%s" is manager' => 'Progetti all\'interno dei quali "%s" è manager',
    'Projects where "%s" is member' => 'Progetti all\'interno dei quali "%s" è membro',
    'Open tasks assigned to "%s"' => 'Compiti aperti assegnati a "%s"',
    'Closed tasks assigned to "%s"' => 'Compiti chiusi assegnati a "%s"',
    'Assign automatically a color based on a priority' => 'Assegna automaticamente un colore in base alla priorità',
    'Overdue tasks for the project(s) "%s"' => 'Task scaduti per il progetto "%s"',
    'Upload files' => 'Carica file',
    'Installed Plugins' => 'Plugin installati',
    'Plugin Directory' => 'Directory dei plugin',
    'Plugin installed successfully.' => 'Plugin installato con successo.',
    'Plugin updated successfully.' => 'Plugin aggiornato con successo.',
    'Plugin removed successfully.' => 'Plugin rimosso con successo.',
    'Subtask converted to task successfully.' => 'Sotto-compito converito in compito con successo.',
    'Unable to convert the subtask.' => 'Impossibile convertire il sotto-compito.',
    'Unable to extract plugin archive.' => 'Impossibile estrarre l\' archivio del plugin.',
    'Plugin not found.' => 'Plugin non trovato.',
    'You don\'t have the permission to remove this plugin.' => 'Non hai i permessi per rimuovere questo plugin.',
    'Unable to download plugin archive.' => 'Impossibile scaricare l\'archivo del plugin',
    'Unable to write temporary file for plugin.' => 'Impossibile scrivere il file temporaneo per il plugin.',
    'Unable to open plugin archive.' => 'Impossibile aprire l\'archivio del plugin.',
    'There is no file in the plugin archive.' => 'Non ci sono file nell\' archivio del plugin.',
    'Create tasks in bulk' => 'Creazione massiva di compiti',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => 'La tua installazione Kanboard non è configurata per installare plugin tramite l\'interfaccia utente.',
    'There is no plugin available.' => 'Non ci sono plugin disponibili.',
    'Install' => 'Installa',
    'Update' => 'Aggiorna',
    'Up to date' => 'Aggiornato',
    'Not available' => 'Non disponibile',
    'Remove plugin' => 'Disinstalla plugin',
    'Do you really want to remove this plugin: "%s"?' => 'Vuoi davvero rimuovere questo plugin: "%s"?',
    'Uninstall' => 'Disinstalla',
    'Listing' => 'Elenco',
    'Metadata' => 'Metadati',
    'Manage projects' => 'Gestione progetti',
    'Convert to task' => 'Converti in compito',
    'Convert sub-task to task' => 'Converti il sotto-compito in compito',
    'Do you really want to convert this sub-task to a task?' => 'Vuoi davvero convertire questo sotto-compito in un compito?',
    'My task title' => 'Titolo del mio compito',
    'Enter one task by line.' => 'Inserisci un compito per ogni riga.',
    'Number of failed login:' => 'Numero di login falliti:',
    'Account locked until:' => 'Account bloccato fino al:',
    'Email settings' => 'Impostazioni Email',
    'Email sender address' => 'Indirizzo Email mittente',
    'Email transport' => 'Trasporto Email',
    'Webhook token' => 'Token Webhook',
    'Project tags management' => 'Gestione tag di progetto',
    'Tag created successfully.' => 'Tag creato con successo.',
    'Unable to create this tag.' => 'Impossibile creare questo tag.',
    'Tag updated successfully.' => 'Tag aggiornato con successo.',
    'Unable to update this tag.' => 'Impossibile aggiornare questo tag.',
    'Tag removed successfully.' => 'Tag rimosso con successo.',
    'Unable to remove this tag.' => 'Impossibile rimuovere questo tag.',
    'Global tags management' => 'Gestione dei tag globali',
    'Tags' => 'Tag',
    'Tags management' => 'Gestione dei tag',
    'Add new tag' => 'Aggiungi un nuovo tag',
    'Edit a tag' => 'Modifica un tag',
    'Project tags' => 'Tag di progetto',
    'There is no specific tag for this project at the moment.' => 'Non è definito nessun tag specifico per questo progetto al momento.',
    'Tag' => 'Tag',
    'Remove a tag' => 'Rimuovi un tag',
    'Do you really want to remove this tag: "%s"?' => 'Vuoi davvero rimuovere questo tag: "%s"?',
    'Global tags' => 'Tag globali',
    'There is no global tag at the moment.' => 'Non sono definiti tag globali al momento.',
    'This field cannot be empty' => 'Questo campo non può essere vuoto',
    'Close a task when there is no activity in a specific column' => 'Chiudi un compito quando non vi è alcuna attività in una specifica colonna',
    '%s removed a subtask for the task #%d' => '%s rimosso un sotto-compito per il compito #%d',
    '%s removed a comment on the task #%d' => '%s rimosso un commento nel compito #%d',
    'Comment removed on task #%d' => 'Commento rimosso nel compito #%d',
    'Subtask removed on task #%d' => 'Sotto-compito rimosso nel compito #%d',
    'Hide tasks in this column in the dashboard' => 'Nascondi i compiti in questa colonna nella dashboard',
    '%s removed a comment on the task %s' => '%s rimosso un commento nel compito %s',
    '%s removed a subtask for the task %s' => '%s rimosso un sotto-compito per il compito %s',
    'Comment removed' => 'Commento rimosso',
    'Subtask removed' => 'Sotto-compito rimosso',
    '%s set a new internal link for the task #%d' => '%s imposta un nuovo link interno per il compito #%d',
    '%s removed an internal link for the task #%d' => '%s rimosso un link interno per il compito #%d',
    'A new internal link for the task #%d has been defined' => 'E\' stato definito un nuovo link interno per il compito #%d',
    'Internal link removed for the task #%d' => 'Link interno rimosso per il compito #%d',
    '%s set a new internal link for the task %s' => '%s imposta un nuovo link interno per il compito %s',
    '%s removed an internal link for the task %s' => '%s rimosso un link interno per il compito %s',
    'Automatically set the due date on task creation' => 'Imposta automaticamente la data di scadenza alla creazione del compito',
    'Move the task to another column when closed' => 'Sposta il compito su un\'altra colonna quando viene chiuso',
    'Move the task to another column when not moved during a given period' => 'Sposta il compito su un\'altra colonna quando non viene spostato entro un certo periodo',
    'Dashboard for %s' => 'Dashboard per %s',
    'Tasks overview for %s' => 'Panoramica dei compiti per %s',
    'Subtasks overview for %s' => 'Panoramica dei compiti per %s',
    'Projects overview for %s' => 'Panoramica dei progetti per %s',
    'Activity stream for %s' => 'Flusso attività per %s',
    'Assign a color when the task is moved to a specific swimlane' => 'Assegna un colore quando il compito viene spostato su una specifica corsia',
    'Assign a priority when the task is moved to a specific swimlane' => 'Assegna una priorità quando il compito viene spostato su una specifica corsia',
    'User unlocked successfully.' => 'Utente sbloccato con successo.',
    'Unable to unlock the user.' => 'Impossibile sbloccare l\'utente.',
    'Move a task to another swimlane' => 'Sposta un compito su un\'altra corsia',
    'Creator Name' => 'Nome del creatore',
    'Time spent and estimated' => 'Tempo trascorso e stima',
    'Move position' => 'Cambia posizione',
    'Move task to another position on the board' => 'Sposta compito su un\'altra posizione nella board',
    'Insert before this task' => 'Inserisci prima di questo compito',
    'Insert after this task' => 'Inserisci dopo questo compito',
    'Unlock this user' => 'Sblocca quest\'utente',
    'Custom Project Roles' => 'Personalizza Ruoli del Progetto',
    'Add a new custom role' => 'Aggiungi un nuovo ruolo personalizzato',
    'Restrictions for the role "%s"' => 'Restrizioni per il ruolo "%s"',
    'Add a new project restriction' => 'Aggiungi una nuova restrizione per il progetto',
    'Add a new drag and drop restriction' => 'Aggiungi una nuova restrizione per il trascinamento',
    'Add a new column restriction' => 'Aggiungi una nuova restrizione per la colonna',
    'Edit this role' => 'Modifica questo ruolo',
    'Remove this role' => 'Cancella questo ruolo',
    'There is no restriction for this role.' => 'Non ci sono restrizioni per questo ruolo.',
    'Only moving task between those columns is permitted' => 'È permesso solo muovere i compiti tra queste colonne',
    'Close a task in a specific column when not moved during a given period' => 'Chiudi un compito in una colonna specifica quando non viene mosso per un determinato periodo',
    'Edit columns' => 'Modifica colonne',
    'The column restriction has been created successfully.' => 'La restrizione per le colonne è stata creata correttamente.',
    'Unable to create this column restriction.' => 'Impossibile creare questa restrizione per colonne.',
    'Column restriction removed successfully.' => 'Restrizione per colonne rimossa correttamente.',
    'Unable to remove this restriction.' => 'Impossibile rimuovere questa restrizione.',
    'Your custom project role has been created successfully.' => 'La regola personalizzata per il progetto è stata creata correttamente.',
    'Unable to create custom project role.' => 'Impossibile creare la regola personalizzata per il progetto.',
    'Your custom project role has been updated successfully.' => 'La regola personalizzata per il progetto è stata modificata correttamente.',
    'Unable to update custom project role.' => 'Impossibile modificare correttamente la regola personalizzata per il progetto.',
    'Custom project role removed successfully.' => 'Regola personalizzata per il progetto rimossa correttamente.',
    'Unable to remove this project role.' => 'Impossibile rimuovere questa regola per il progetto.',
    'The project restriction has been created successfully.' => 'La restrizione di progetto è stata creata con successo.',
    'Unable to create this project restriction.' => 'Impossibile creare la restrizione di progetto.',
    'Project restriction removed successfully.' => 'Restrizione di progetto rimossa correttamente.',
    'You cannot create tasks in this column.' => 'Non puoi creare dei compiti in questa colonna.',
    'Task creation is permitted for this column' => 'La creazione di compiti è permessa per questa colonna',
    'Closing or opening a task is permitted for this column' => 'Chiudere o aprire compito è permesso per questa colonna',
    'Task creation is blocked for this column' => 'La creazione di compiti è bloccata per questa colonna',
    'Closing or opening a task is blocked for this column' => 'Chiudere o aprire compito è bloccato per questa colonna',
    'Task creation is not permitted' => 'Creazione compito non permessa',
    'Closing or opening a task is not permitted' => 'Chiudere o aprire compito non è permesso',
    'New drag and drop restriction for the role "%s"' => 'Nuova restrizione "drag and drop" per la regola "%s"',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => 'Gli utenti che appartengono a questa regola saranno in grado di spostare i compiti solo tra la colonna di origine e quella di destinazione',
    'Remove a column restriction' => 'Rimuovere una restrizione di colonna',
    'Do you really want to remove this column restriction: "%s" to "%s"?' => 'Vuoi davvero rimuovere questa restrizione di colonna: "%s" a "%s"?',
    'New column restriction for the role "%s"' => 'Nuova restrizione di colonna per la regola "%s"',
    'Rule' => 'Regola',
    'Do you really want to remove this column restriction?' => 'Vuoi davvero rimuovere questa restrizione di colonna?',
    'Custom roles' => 'Regole personalizzate',
    'New custom project role' => 'Nuova regola per progetto personalizzato',
    'Edit custom project role' => 'Modifica regola per progetto personalizzato',
    'Remove a custom role' => 'Rimuovi regola personalizzata',
    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => 'Vuoi davvero rimuovere questa regola personalizzata: "%s"? Tutti gli utenti assegnati a questa regola diventeranno membri del progetto',
    'There is no custom role for this project.' => 'Non c\'è regola personalizzata per questo progetto.',
    'New project restriction for the role "%s"' => 'Nuova restrizione di progetto per la regola "%s"',
    'Restriction' => 'Restrizione',
    'Remove a project restriction' => 'Rimuovi restrizione di progetto',
    'Do you really want to remove this project restriction: "%s"?' => 'Vuoi davvero rimuovere questa restrizione di progetto: "%s"?',
    'Duplicate to multiple projects' => 'Duplica su più progetti',
    'This field is required' => 'Questo campo è obbligatorio',
    'Moving a task is not permitted' => 'Spostare un compito non è permesso',
    'This value must be in the range %d to %d' => 'Questo valore deve essere compreso tra %d e %d',
    'You are not allowed to move this task.' => 'Non ti è permesso spostare questo compito.',
    'API User Access' => 'API per l\'accesso utente',
    'Preview' => 'Anteprima',
    'Write' => 'Scrivi',
    'Write your text in Markdown' => 'Scrivi il tuo testo in Markdown',
    'No personal API access token registered.' => 'Nessun token di accesso API personale registrato.',
    'Your personal API access token is "%s"' => 'Il tuo token di accesso API personale è "%s"',
    'Remove your token' => 'Rimuovi il tuo token',
    'Generate a new token' => 'Genera un nuovo token',
    'Showing %d-%d of %d' => 'Visualizzazione %d-%d di %d',
    'Outgoing Emails' => 'Email in uscita',
    'Add or change currency rate' => 'Aggiungi o modifica la valuta di riferimento',
    'Reference currency: %s' => 'Valuta di riferimento: %s',
    'Add custom filters' => 'Aggiungi filtri personalizzati',
    'Export' => 'Esporta',
    'Add link label' => 'Aggiungi un\'etichetta al link',
    'Incompatible Plugins' => 'Plugin incompatibili',
    'Compatibility' => 'Compatibilità',
    'Permissions and ownership' => 'Permessi e assegnazioni',
    'Priorities' => 'Priorità',
    'Close this window' => 'Chiudi questa finestra',
    'Unable to upload this file.' => 'Non è stato possibile caricare questo file.',
    'Import tasks' => 'Importa compiti',
    'Choose a project' => 'Scegli un progetto',
    'Profile' => 'Profilo',
    'Application role' => 'Ruolo applicativo',
    '%d invitations were sent.' => 'Sono stati spediti %d inviti.',
    '%d invitation was sent.' => 'E\' stato spedito %d invito.',
    'Unable to create this user.' => 'Non è stato possibile creare questo utente.',
    'Kanboard Invitation' => 'Invito a Kanboard',
    'Visible on dashboard' => 'Visibile sulla dashboard',
    'Created at:' => 'Creato il:',
    'Updated at:' => 'Aggiornato il:',
    'There is no custom filter.' => 'Non c\'è alcun filtro personalizzato.',
    'New User' => 'Nuovo Utente',
    'Authentication' => 'Autenticazione',
    'If checked, this user will use a third-party system for authentication.' => 'Quando selezionato, l\'utente utilizzerà un sistema di terza parte per l\'autenticazione.',
    'The password is necessary only for local users.' => 'La password è obbligatoria solo per gli utenti locali.',
    'You have been invited to register on Kanboard.' => 'Sei stato invitato a registrarti su Kanboard.',
    'Click here to join your team' => 'Clicca qui per accedere al tuo gruppo di lavoro',
    'Invite people' => 'Invita altre persone',
    'Emails' => 'Emails',
    'Enter one email address by line.' => 'Inserisci un indirizzo email per riga.',
    'Add these people to this project' => 'Aggiungi queste persone al progetto',
    'Add this person to this project' => 'Aggiungi questa persona al progetto',
    'Sign-up' => 'Registrati',
    'Credentials' => 'Credenziali',
    'New user' => 'Nuovo utente',
    'This username is already taken' => 'Questo nome utente esiste già',
    'Your profile must have a valid email address.' => 'Il tuo profilo deve avere un indirizzo email valido.',
    'TRL - Turkish Lira' => 'TRL - Lira Turca',
    'The project email is optional and could be used by several plugins.' => 'L\'email del progetto è opzionale e può essere utilizzata da plugin differenti.',
    'The project email must be unique across all projects' => 'L\'email del progetto deve essere univoca tra tutti i progetti',
    'The email configuration has been disabled by the administrator.' => 'La configurazione della email è stata disabilitata dall\'amministratore',
    'Close this project' => 'Chiudi questo progetto',
    'Open this project' => 'Apri questo progetto',
    'Close a project' => 'Chiudi un progetto',
    'Do you really want to close this project: "%s"?' => 'Vuoi chiudere veramente questo progetto: "%s"? ',
    'Reopen a project' => 'Riapri un progetto',
    'Do you really want to reopen this project: "%s"?' => 'Vuoi riaprire veramente questo progetto: "%s"?',
    'This project is open' => 'Questo progetto è aperto',
    'This project is closed' => 'Questo progetto è chiuso',
    'Unable to upload files, check the permissions of your data folder.' => 'Non è stato possibile caricare i file, verifica i permessi della cartella contenente i dati.',
    'Another category with the same name exists in this project' => 'Esiste già una categoria con lo stesso nome in questo progetto',
    'Comment sent by email successfully.' => 'Commento inviato per email con successo.',
    'Sent by email to "%s" (%s)' => 'Inviato per email a "%s" (%s)',
    'Unable to read uploaded file.' => 'Non è stato possibile leggere il file caricato.',
    'Database uploaded successfully.' => 'Database caricato con successo.',
    'Task sent by email successfully.' => 'Task inviato per email con successo.',
    'There is no category in this project.' => 'Non esiste alcuna categoria in questo progetto.',
    'Send by email' => 'Invia per email',
    'Create and send a comment by email' => 'Crea ed invia un commento per email',
    'Subject' => 'Oggetto',
    'Upload the database' => 'Carica il database',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => 'Puoi caricare il database Sqlite precedentemente scaricato (Gzip format).',
    'Database file' => 'File del database',
    'Upload' => 'Carica',
    'Your project must have at least one active swimlane.' => 'Il tuo progetto deve avere almeno una corsia attiva.',
    'Project: %s' => 'Progetto: %s',
    'Automatic action not found: "%s"' => 'Azione automatica non trovata: "%s"',
    '%d projects' => '%d progetti',
    '%d project' => '%d progetto',
    'There is no project.' => 'Non esiste alcun progetto.',
    'Sort' => 'Ordina',
    'Project ID' => 'ID progetto',
    'Project name' => 'Nome del progetto',
    'Public' => 'Pubblico',
    'Personal' => 'Privato',
    '%d tasks' => '%d dei compiti',
    '%d task' => '%d del compito',
    'Task ID' => 'ID del compito',
    'Assign automatically a color when due date is expired' => 'Assegna automaticamente un colore quando la data di scadenza è stata raggiunta',
    'Total score in this column across all swimlanes' => 'Punteggio totale di questa colonna in tutte le corsie',
    'HRK - Kuna' => 'HRK - Kuna',
    'ARS - Argentine Peso' => 'ARS - Peso Argentino',
    'COP - Colombian Peso' => 'COP - Peso Colombiano',
    '%d groups' => '%d gruppi',
    '%d group' => '%d gruppo',
    'Group ID' => 'ID gruppo',
    'External ID' => 'ID esterno',
    '%d users' => '%d utenti',
    '%d user' => '%d utente',
    'Hide subtasks' => 'Nascondi sotto-compiti',
    'Show subtasks' => 'Mostra sotto-compiti',
    'Authentication Parameters' => 'Parametri di Autenticazione',
    'API Access' => 'Accesso API',
    'No users found.' => 'Nessun utente trovato.',
    'User ID' => 'ID utente',
    'Notifications are activated' => 'Le notifiche sono attivate',
    'Notifications are disabled' => 'Le notifiche sono disattivate',
    'User disabled' => 'Utente disabilitato',
    '%d notifications' => '%d notifiche',
    '%d notification' => '%d notifica',
    'There is no external integration installed.' => 'Nessuna integrazione esterna installata.',
    'You are not allowed to update tasks assigned to someone else.' => 'Non sei abilitato ad aggiornare i compiti assegnati a qualcun altro.',
    'You are not allowed to change the assignee.' => 'Non sei abilitato a modificare l\'assegnatario',
    'Task suppression is not permitted' => 'L\'eliminazione del compito non è permessa',
    'Changing assignee is not permitted' => 'Non è permesso modificare l\'assegnatario',
    'Update only assigned tasks is permitted' => 'E\' permesso aggiornare solo i compiti assegnati',
    'Only for tasks assigned to the current user' => 'Solo per i compiti assegnati all\'utente corrente',
    'My projects' => 'I miei progetti',
    'You are not a member of any project.' => 'Non sei membro di alcun progetto.',
    'My subtasks' => 'I miei sotto-compiti',
    '%d subtasks' => '%d sotto-compiti',
    '%d subtask' => '%d sotto-compiti',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => 'I compiti assegnati all\'utente corrente possono essere solo spostati in quelle colonne',
    '[DUPLICATE]' => '[DUPLICA]',
    'DKK - Danish Krona' => 'DKK - Corona Danese',
    'Remove user from group' => 'Rimuovi utente dal gruppo',
    'Assign the task to its creator' => 'Assegna il compito al suo creatore',
    'This task was sent by email to "%s" with subject "%s".' => 'Questo compito è stato inviato per email a "%s" con oggetto "%s".',
    'Predefined Email Subjects' => 'Oggetti email predefiniti',
    'Write one subject by line.' => 'Scrivi un oggetto per riga.',
    'Create another link' => 'Crea un altro link',
    'BRL - Brazilian Real' => 'BRL - Real Brasiliano',
    'Add a new Kanboard task' => 'Crea un nuovo compito Kanboard',
    'Subtask not started' => 'Sotto-compito non iniziato',
    'Subtask currently in progress' => 'Sotto-compito attualmente in corso',
    'Subtask completed' => 'Sotto-compito completato',
    'Subtask added successfully.' => 'Sotto-compito aggiunto con successo.',
    '%d subtasks added successfully.' => '%d sotto-compiti aggiunti con successo.',
    'Enter one subtask by line.' => 'Inserisci un sotto-compito per riga.',
    'Predefined Contents' => 'Contenuti Predefiniti',
    'Predefined contents' => 'Contenuti predefiniti',
    'Predefined Task Description' => 'Descrizione predefinita del compito',
    'Do you really want to remove this template? "%s"' => 'Vuoi eliminare veramente questo template? "%s"',
    'Add predefined task description' => 'Aggiungi una descrizione predefinita del compito',
    'Predefined Task Descriptions' => 'Descrizioni predefinite dei compito',
    'Template created successfully.' => 'Il template è stato creato correttamente.',
    'Unable to create this template.' => 'Non è stato possibile creare questo template.',
    'Template updated successfully.' => 'Template aggiornato con successo.',
    'Unable to update this template.' => 'Non è stato possibile aggiornare questo template.',
    'Template removed successfully.' => 'Template eliminato con successo.',
    'Unable to remove this template.' => 'Non è stato possibile eliminare questo template.',
    'Template for the task description' => 'Template per la descrizione del compito',
    'The start date is greater than the end date' => 'La data di inizio è superiore alla data di fine',
    'Tags must be separated by a comma' => 'I tag devono essere separati da una virgola',
    'Only the task title is required' => 'Solo il titolo del compito è obbligatorio',
    'Creator Username' => 'Nome utente del creatore',
    'Color Name' => 'Nome del colore',
    'Column Name' => 'Nome della colonna',
    'Swimlane Name' => 'Nome della corsia',
    'Time Estimated' => 'Tempo stimato',
    'Time Spent' => 'Tempo effettivo',
    'External Link' => 'Link esterno',
    'This feature enables the iCal feed, RSS feed and the public board view.' => 'Questa funzionalità abilita il feed iCal, il feed RSS e la visualizzazione pubblica della dashboard',
    'Stop the timer of all subtasks when moving a task to another column' => 'Interrompi il timer di tutti i sotto-compiti quando un compito viene spostato in un\'altra colonna',
    'Subtask Title' => 'Titolo del sotto-compito',
    'Add a subtask and activate the timer when moving a task to another column' => 'Aggiungi un sotto-compito e attiva il timer quando un compito viene spostato in un\'altra colonna',
    'days' => 'giorni',
    'minutes' => 'minuti',
    'seconds' => 'secondi',
    'Assign automatically a color when preset start date is reached' => 'Assegna automaticamente un colore quando la data di inzio prestabilita viene raggiunta',
    'Move the task to another column once a predefined start date is reached' => 'Sposta il compito in un\'altra colonna quando si raggiunge una data predefinita',
    'This task is now linked to the task %s with the relation "%s"' => 'Questo compito è ora collegato al compito %s tramite la relazione "%s"',
    'The link with the relation "%s" to the task %s has been removed' => 'Il collegamento con la relazione "%s" al compito %s è stato rimosso',
    'Custom Filter:' => 'Filtro personalizzato',
    'Unable to find this group.' => 'Non è stato possibile trovare questo gruppo',
    '%s moved the task #%d to the column "%s"' => '%s ha spostato il compito #%d nella colonna "%s"',
    '%s moved the task #%d to the position %d in the column "%s"' => '%s ha spostato il compito #%d a posizione %d nella colonna "%s"',
    '%s moved the task #%d to the swimlane "%s"' => '%s ha spostato il compito #%d nella corsia "%s"',
    '%sh spent' => '%sh effettive',
    '%sh estimated' => '%sh stimate',
    'Select All' => 'Seleziona tutti',
    'Unselect All' => 'Deseleziona tutti',
    'Apply action' => 'Applica azione',
    'Move selected tasks to another column or swimlane' => 'Sposta i compiti selezionati in un\'altra colonna',
    'Edit tasks in bulk' => 'Modifica i compiti massivamente',
    'Choose the properties that you would like to change for the selected tasks.' => 'Scegli le proprietà che vorresti modificare per i compiti selezionato.',
    'Configure this project' => 'Configura questo progetto',
    'Start now' => 'Inizia ora',
    '%s removed a file from the task #%d' => '%s ha rimosso un file dal compito #%d',
    'Attachment removed from task #%d: %s' => 'Allegato rimosso dal compito #%d: %s',
    'No color' => 'Nessun colore',
    'Attachment removed "%s"' => 'Allegato rimosso "%s"',
    '%s removed a file from the task %s' => '%s ha rimosso un file dal compito %s',
    'Move the task to another swimlane when assigned to a user' => 'Sposta il compito in un\'altra corsia quando viene assegnato ad un utente',
    'Destination swimlane' => 'Corsia di destinazione',
    'Assign a category when the task is moved to a specific swimlane' => 'Assegna una categoria quando il compito viene spostato in una corsia specifica',
    'Move the task to another swimlane when the category is changed' => 'Sposta il compito in un\'altra corsia quando la categoria viene modificata',
    'Reorder this column by priority (ASC)' => 'Ordina questa colonna per priorità (ASC)',
    'Reorder this column by priority (DESC)' => 'Ordina questa colonna per priorità (DESC)',
    'Reorder this column by assignee and priority (ASC)' => 'Ordina questa colonna per assegnatario e per priorità (ASC)',
    'Reorder this column by assignee and priority (DESC)' => 'Ordina questa colonna per assegnatario e per priorità (DESC)',
    'Reorder this column by assignee (A-Z)' => 'Ordina questa colonna per assegnatario (ASC)',
    'Reorder this column by assignee (Z-A)' => 'Ordina questa colonna per assegnatario (DESC)',
    'Reorder this column by due date (ASC)' => 'Riordina questa colonna per dat di scadenza (ASCENDENTE)',
    'Reorder this column by due date (DESC)' => 'Riordina questa colonna per dat di scadenza (DISCENDENTE)',
    'Reorder this column by id (ASC)' => 'Riordina questa colonna per ID (ASC)',
    'Reorder this column by id (DESC)' => 'Riordina questa colonna per ID (DESC)',
    '%s moved the task #%d "%s" to the project "%s"' => '%s ha spostato il compito #%d "%s" al progetto "%s"',
    'Task #%d "%s" has been moved to the project "%s"' => 'Il compito #%d "%s"è stato spostato al progetto "%s"',
    'Move the task to another column when the due date is less than a certain number of days' => 'Sposta il compito ad un\'altra colonna se la dat di scadenza è più vicina di un certo numero di giorni',
    'Automatically update the start date when the task is moved away from a specific column' => 'Aggiorna automaticamente la data di inizio quando il compito è tolto da una colonna specifica',
    'HTTP Client:' => 'Client HTTP',
    'Assigned' => 'Assegnato',
    'Task limits apply to each swimlane individually' => 'I limiti di compito si applicano individualmente ad ogni corsia',
    'Column task limits apply to each swimlane individually' => 'I limiti di compito per colonna si applicano individualmente ad ogni corsia',
    'Column task limits are applied to each swimlane individually' => 'I limiti di compito per colonna vengono applicati individualmente ad ogni corsia',
    'Column task limits are applied across swimlanes' => 'I limiti di compito per colonna vengono applicati a tutte le corsie',
    'Task limit: ' => 'Limite di compito',
    'Change to global tag' => 'Modifica all\'etichetta globale',
    'Do you really want to make the tag "%s" global?' => 'Vuoi davvero rendere globale l\'etichetta "%s"?',
    'Enable global tags for this project' => 'Abilita le etichette globali per questo progetto',
    'Group membership(s):' => 'Assegnazioni di gruppo',
    '%s is a member of the following group(s): %s' => '%s è membro dei gruppi seguenti: %s',
    '%d/%d group(s) shown' => '%d/%d gruppi mostrati',
    'Subtask creation or modification' => 'Creazione o modifica sotto-compiti',
    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Assegna il compito ad un utente specifico quando il compito viene spostato ad una corsia specifica',
    'Comment' => 'Commento',
    'Collapse vertically' => 'Riduci verticalmente',
    'Expand vertically' => 'Espandi verticalmente',
    'MXN - Mexican Peso' => 'MXN - Peso messicano',
    'Estimated vs actual time per column' => 'Tempo stimato vs reale per colonna',
    'HUF - Hungarian Forint' => 'HUF - Fiorino ungherese',
    'XBT - Bitcoin' => 'XBT - Bitcoin',
    'You must select a file to upload as your avatar!' => 'Devi selezionare un file da caricare come avatar!',
    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Il file caricato non è un\'immagine valida! (Sono consentiti solo *.gif, *.jpg, *.jpeg e *.png!)',
    'Automatically set the due date when the task is moved away from a specific column' => 'Imposta automaticamente la data di scadenza quando il task viene spostato da una colonna specifica',
    'No other projects found.' => 'Nessun altro progetto trovato.',
    'Tasks copied successfully.' => 'Attività copiate con successo.',
    'Unable to copy tasks.' => 'Impossibile copiare le attività.',
    'Theme' => 'Tema',
    'Theme:' => 'Tema:',
    'Light theme' => 'Tema chiaro',
    'Dark theme' => 'Tema scuro',
    'Automatic theme - Sync with system' => 'Tema automatico - Sincronizza con il sistema',
    'Application managers or more' => 'Gestori dell\'applicazione o più',
    'Administrators' => 'Amministratori',
    'Visibility:' => 'Visibilità:',
    'Standard users' => 'Utenti standard',
    'Visibility is required' => 'La visibilità è obbligatoria',
    'The visibility should be an app role' => 'La visibilità deve essere un ruolo dell\'applicazione',
    'Reply' => 'Rispondi',
    '%s wrote: ' => '%s ha scritto: ',
    'Number of visible tasks in this column and swimlane' => 'Numero di attività visibili in questa colonna e swimlane',
    'Number of tasks in this swimlane' => 'Numero di attività in questa swimlane',
    'Unable to find another subtask in progress, you can close this window.' => 'Impossibile trovare un\'altra sotto-attività in corso, puoi chiudere questa finestra.',
    'This theme is invalid' => 'Questo tema non è valido',
    'This role is invalid' => 'Questo ruolo non è valido',
    'This timezone is invalid' => 'Questo fuso orario non è valido',
    'This language is invalid' => 'Questa lingua non è valida',
    'This URL is invalid' => 'Questo URL non è valido',
    'Date format invalid' => 'Formato data non valido',
    'Time format invalid' => 'Formato ora non valido',
    'Invalid Mail transport' => 'Trasporto email non valido',
    'Color invalid' => 'Colore non valido',
    'This value must be greater or equal to %d' => 'Questo valore deve essere maggiore o uguale a %d',
    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Aggiungi un BOM all\'inizio del file (richiesto per Microsoft Excel)',
    'Just add these tag(s)' => 'Aggiungi solo queste etichette',
    'Remove internal link(s)' => 'Rimuovi i collegamenti interni',
    'Import tasks from another project' => 'Importa attività da un altro progetto',
    'Select the project to copy tasks from' => 'Seleziona il progetto da cui copiare le attività',
    'The total maximum allowed attachments size is %sB.' => 'La dimensione massima totale consentita per gli allegati è %sB.',
    'Add attachments' => 'Aggiungi allegati',
    'Task #%d "%s" is overdue' => 'Il compito #%d "%s" è scaduto',
    'Enable notifications by default for all new users' => 'Abilita le notifiche per impostazione predefinita per tutti i nuovi utenti',
    'Assign the task to its creator for specific columns if no assignee is set manually' => 'Assegna l\'attività al suo creatore per colonne specifiche se non è stato impostato manualmente alcun assegnatario',
    'Assign a task to the logged user on column change to specified column if no user is assigned' => 'Assegna un\'attività all\'utente connesso al cambio di colonna verso la colonna specificata se nessun utente è assegnato',
];
